/*
 * ErrorInterface.java
 *
 * Created on December 17, 2002, 5:23 PM
 *
 * This software is copyright (c) 2002 Board of Regents, University of Wisconsin.
 * All Rights Reserved.
 */

package EDU.bmrb.starch;

/**
 * Error interface: defines methods for adding/retrieving error messages.
 * @author  dmaziuk
 * @version 
 */
public interface ErrorInterface {
//
// ValidateErrorInterface: methods for manipulating error list
//
    /** Adds warning message.
     * This method adds formatted message to the list of conversion error/warning 
     * messages. If verbose flag is false, message is not added.
     * @param linenum line number
     * @param seqcode sequence code
     * @param label residue label
     * @param msg String message
     * @see #addError( String )
     * @see Converter#read( BufferedReader )
     */
    public void addWarning( int linenum, String seqcode, String label, String msg );
    /** Adds warning message.
     * This method adds formatted message to the list of conversion error/warning 
     * messages. If verbose flag is false, message is not added.
     * @param seqcode sequence code
     * @param label residue label
     * @param msg String message
     * @see #addError( String )
     * @see Converter#read( BufferedReader )
     */
    public void addWarning( String seqcode, String label, String msg );
    /** Adds warning message.
     * This method adds String to the list of conversion error/warning messages.
     * If verbose flag is false, message is not added.
     * @param linenum line number
     * @param msg String message
     * @see #addError( String )
     * @see Converter#read( BufferedReader )
     */
    public void addWarning( int linenum, String msg );
    /** Adds warning message.
     * This method adds String to the list of conversion error/warning messages.
     * If verbose flag is false, message is not added.
     * @param msg String message
     * @see #addError( String )
     * @see Converter#read( BufferedReader )
     */
    public void addWarning( String msg );
    /** Adds error message.
     * This method adds formatted error message to the list of conversion 
     * error/warning messages. Unlike addWarning(), this method ignores verbose 
     * flag.
     * @param linenum line number
     * @param seqcode sequence code
     * @param label residue label
     * @param msg String message
     * @see #addWarning( String )
     * @see Converter#read( BufferedReader )
     */
    public void addError( int linenum, String seqcode, String label, String msg ); 
    /** Adds error message.
     * This method adds formatted error message to the list of conversion 
     * error/warning messages. Unlike addWarning(), this method ignores verbose 
     * flag.
     * @param seqcode sequence code
     * @param label residue label
     * @param msg String message
     * @see #addWarning( String )
     * @see Converter#read( BufferedReader )
     */
    public void addError( String seqcode, String label, String msg );
    /** Adds error message.
     * This method adds String to the list of conversion error/warning messages.
     * Unlike addWarning(), this method ignores verbose flag.
     * @param linenum line number
     * @param msg String message
     * @see #addWarning( String )
     * @see Converter#read( BufferedReader )
     */
    public void addError( int linenum, String msg );
    /** Adds error message.
     * This method adds String to the list of conversion error/warning messages.
     * Unlike addWarning(), this method ignores verbose flag.
     * @param msg String message
     * @see #addWarning( String )
     * @see Converter#read( BufferedReader )
     */
    public void addError( String msg );
    /** Returns error count.
     * Returns number of messages in the list of conversion errors/warnings.
     * Application should check this number after Converter.read() has returned, 
     * regardless of the return value: Converter.read() returns false on critical 
     * errors only.
     * @return int message count
     * @see Converter#read( BufferedReader )
     */
    public int numErrors();
    /** Returns error message at specified index.
     * Returns message from the list of conversion errors/warnings.
     * @param index int message index
     * @return String message or null
     */
    public String errorAt( int index );
    /** Clears list of conversion errors/warnings.
     */
    public void removeAllErrors();
    /** Returns error messages as one (possibly huge) String.
     * Use printErrors() instead.
     * @return String error messages
     * @see #printErrors( PrintWriter )
     */
    public String getErrors();
    /** Prints out error messages.
     * @param out PrintWriter output stream
     * @return false if there was an error, true otherwise
     */
    public boolean printErrors( java.io.PrintWriter out );
}

